@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
+"""Pin definitions for the Binho Nova"""
 from adafruit_blinka.microcontroller.nova import pin
 
 IO0 = pin.IO0
