@@ -1,4 +1,7 @@
-"""Feather Huzzah pin names"""
+# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
+"""Pin definitions for the Feather Huzzah."""
 
 from adafruit_blinka.microcontroller.esp8266 import pin
 
